dsqlsea

package module
v0.1.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 3, 2026 License: MIT Imports: 0 Imported by: 0

README

dsqlsea: A Dynamic SQL Compiler (temporary hard fork of sqlc)

⚠️ Temporary hard fork

This repository is a temporary hard fork of sqlc-dev/sqlc. It exists so we can experiment with opinionated support for dynamic queries in sqlc. Once the upstream community has a satisfactory dynamic-query solution, this fork should be deprecated in favor of sqlc itself.

go Go Report Card

dsqlsea (CLI: dsql) generates type-safe code from SQL. It is based directly on sqlc; see the upstream overview and playground for the original motivation.

Overview

Supported languages

Additional languages can be added via upstream plugins.

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Placeholder

type Placeholder struct{}

Directories

Path Synopsis
cmd
dsql command
sqlc-gen-json command
sqlc-test-setup command
examples
internal
cmd
ext
rpc
sqlcdebug
Package sqlcdebug parses the SQLCDEBUG environment variable and exposes its key=value settings to the rest of the codebase.
Package sqlcdebug parses the SQLCDEBUG environment variable and exposes its key=value settings to the rest of the codebase.
vet
pkg
cli
package cli exposes the command-line interface for sqlc.
package cli exposes the command-line interface for sqlc.
build command
bump-version command

Jump to